@@ -1,7 +1,7 @@
 #  coding: utf-8
 #  ----------------------------------------------------------------------------
 #  <copyright company="Aspose" file="imaging_api.py">
-#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
+#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
 #  </copyright>
 #  <summary>
 #    Permission is hereby granted, free of charge, to any person obtaining a
@@ -220,6 +220,26 @@ class ImagingApi(object):
         http_request = request.to_http_info(self.api_client.configuration)
         return self.__make_request_async(http_request, 'POST', 'file')
 
+    def create_fax_tiff(self, request):
+        """Update parameters of TIFF image accordingly to fax parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+
+
+        :param request create_fax_tiff_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request(http_request, 'POST', 'file')
+
+    def create_fax_tiff_async(self, request):
+        """Update parameters of TIFF image accordingly to fax parameters. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+
+
+        :param request create_fax_tiff_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request_async(http_request, 'POST', 'file')
+
     def create_folder(self, request):
         """Create the folder
 
@@ -281,7 +301,7 @@ class ImagingApi(object):
         return self.__make_request_async(http_request, 'POST', None)
 
     def create_image_frame(self, request):
-        """Get separate frame from existing TIFF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
 
 
         :param request create_image_frame_request object with parameters
@@ -291,7 +311,7 @@ class ImagingApi(object):
         return self.__make_request(http_request, 'POST', 'file')
 
     def create_image_frame_async(self, request):
-        """Get separate frame from existing TIFF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
 
 
         :param request create_image_frame_request object with parameters
@@ -300,6 +320,26 @@ class ImagingApi(object):
         http_request = request.to_http_info(self.api_client.configuration)
         return self.__make_request_async(http_request, 'POST', 'file')
 
+    def create_image_frame_range(self, request):
+        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+
+
+        :param request create_image_frame_range_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request(http_request, 'POST', 'file')
+
+    def create_image_frame_range_async(self, request):
+        """Get separate frame from existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+
+
+        :param request create_image_frame_range_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request_async(http_request, 'POST', 'file')
+
     def create_image_search(self, request):
         """Create new search context.
 
@@ -821,7 +861,7 @@ class ImagingApi(object):
         return self.__make_request_async(http_request, 'GET', 'ImageFeatures')
 
     def extract_image_frame_properties(self, request):
-        """Get separate frame properties of existing TIFF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+        """Get separate frame properties of existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
 
 
         :param request extract_image_frame_properties_request object with parameters
@@ -831,7 +871,7 @@ class ImagingApi(object):
         return self.__make_request(http_request, 'POST', 'ImagingResponse')
 
     def extract_image_frame_properties_async(self, request):
-        """Get separate frame properties of existing TIFF image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
+        """Get separate frame properties of existing image. Image data is passed as zero-indexed multipart/form-data content or as raw body stream.
 
 
         :param request extract_image_frame_properties_request object with parameters
@@ -1021,7 +1061,7 @@ class ImagingApi(object):
         return self.__make_request_async(http_request, 'GET', 'ImageFeatures')
 
     def get_image_frame(self, request):
-        """Get separate frame from existing TIFF image.
+        """Get separate frame from existing image.
 
 
         :param request get_image_frame_request object with parameters
@@ -1031,7 +1071,7 @@ class ImagingApi(object):
         return self.__make_request(http_request, 'GET', 'file')
 
     def get_image_frame_async(self, request):
-        """Get separate frame from existing TIFF image.
+        """Get separate frame from existing image.
 
 
         :param request get_image_frame_request object with parameters
@@ -1041,7 +1081,7 @@ class ImagingApi(object):
         return self.__make_request_async(http_request, 'GET', 'file')
 
     def get_image_frame_properties(self, request):
-        """Get separate frame properties of existing TIFF image.
+        """Get separate frame properties of existing image.
 
 
         :param request get_image_frame_properties_request object with parameters
@@ -1051,7 +1091,7 @@ class ImagingApi(object):
         return self.__make_request(http_request, 'GET', 'ImagingResponse')
 
     def get_image_frame_properties_async(self, request):
-        """Get separate frame properties of existing TIFF image.
+        """Get separate frame properties of existing image.
 
 
         :param request get_image_frame_properties_request object with parameters
@@ -1060,6 +1100,26 @@ class ImagingApi(object):
         http_request = request.to_http_info(self.api_client.configuration)
         return self.__make_request_async(http_request, 'GET', 'ImagingResponse')
 
+    def get_image_frame_range(self, request):
+        """Get frames range from existing image.
+
+
+        :param request get_image_frame_range_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request(http_request, 'GET', 'file')
+
+    def get_image_frame_range_async(self, request):
+        """Get frames range from existing image.
+
+
+        :param request get_image_frame_range_request object with parameters
+        :return: file
+        """
+        http_request = request.to_http_info(self.api_client.configuration)
+        return self.__make_request_async(http_request, 'GET', 'file')
+
     def get_image_properties(self, request):
         """Get properties of an image.
 
